#
# spec file for package pari
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pari
%define lname	libpari-gmp5
Version:        2.9.3
Release:        lp151.2.3
Summary:        Computer Algebra System for fast computations in Number Theory
License:        GPL-2.0
Group:          Productivity/Scientific/Math
Url:            http://pari.math.u-bordeaux.fr/

#Git-Clone:	http://pari.math.u-bordeaux.fr/git/pari.git
#Git-Web:	http://pari.math.u-bordeaux.fr/cgi-bin/gitweb.cgi
Source:         http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%version.tar.gz
Source2:        http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%version.tar.gz.asc
Source3:        http://pari.math.u-bordeaux.fr/pub/pari/unix/pari-%version.changelog
Patch1:         pari-nodate.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fltk-devel
BuildRequires:  gmp-devel
BuildRequires:  libX11-devel
BuildRequires:  libqt4-devel
BuildRequires:  readline-devel
BuildRequires:  xorg-x11-proto-devel

%description
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%package gp
Summary:        Frontend to the PARI Computer Algebra System
Group:          Productivity/Scientific/Math

%description gp
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%package -n %lname
Summary:        Computer Algebra System library for fast computations in Number Theory
# This is used by the data packages to avoid having a too-old version of libpari:
Group:          System/Libraries
Provides:       libpari-gmp = %version-%release

%description -n %lname
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%package devel
Summary:        Development files for the PARI CAS
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
PARI/GP is a computer algebra system designed for fast computations
in number theory (factorizations, algebraic number theory, elliptic
curves), but also contains a large number of other useful functions
to compute with mathematical entities such as matrices, polynomials,
power series, algebraic numbers etc., and a lot of transcendental
functions.

%prep
%setup -q
%patch -p 1 -P 1

%build
./Configure --prefix="%_prefix" \
	--bindir="%_bindir" --includedir="%_includedir" \
	--libdir="%_libdir" \
	--sysdatadir="%_libdir" --datadir="%_datadir/%name";
make %{?_smp_mflags} all \
	CFLAGS="%optflags -fno-strict-aliasing" \
	STRIP=true;

cp "%{S:3}" .;

%install
b="%buildroot";
make install DESTDIR="$b";

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files gp
%defattr(-,root,root)
%_bindir/*
%_datadir/%name
%_libdir/%name.cfg
%_mandir/man*/*
%doc %name-%version.changelog

#
# See
# http://pari.math.u-bordeaux.fr/archives/pari-dev-1211/msg00006.html
# for details on the SO versioning.
#
%files -n libpari-gmp5
%defattr(-,root,root)
%_libdir/libpari-gmp.so.%version
%_libdir/libpari-gmp.so.5

%files devel
%defattr(-,root,root)
%_includedir/pari
%_libdir/libpari.so

%changelog
* Sat Sep  9 2017 jengelh@inai.de
- Update to new upstream release 2.9.3
  * Expression "issquare(Mod(1,67)*x^4+Mod(14,67)*x^2+Mod(49,67))"
    and "polroots(t_POL whose coeffs vary by a factor > 2^100000)"
    had caused SIGSEGV
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 2.9.1
  * lfunartin was using too much stack
  * fflog in char 3 or 5 was slower than intended
  * modular algorithms could fail for very large input
* Tue Nov 29 2016 jengelh@inai.de
- Update to new upstream release 2.9.0
  * fixed nfisisom(x,x^0) causing a crash
  * fixed crash on BIB in ellpointtoz(t_PADIC)
  * fixed wrong result for nfroots(non-monic t_POL)
  * fixed division by zero on doing
  e=ellinit([1,-1,1,98,126],O(5^10)); ellpointtoz(e,[1,14])
  * fixed rare crash in bnfisprincipal
* Sun Jul 31 2016 jengelh@inai.de
- Update to new upstream release 2.7.6
  * fixed O(1)==O(x) returning 0
  * matsolve(a,b) and a^(-1) gave wrong results [or SEGV] when t_MAT
  a was not square and a,b "modular"; same for x^(-1)
  * fixed a memory leak in pari_close: sopath was not freed
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 2.7.5
  * forprime engine could skip (fast) sieve in favour of (slow)
  * corrected return values/exceptions of functions
* Thu Feb 26 2015 jengelh@inai.de
- Update to new upstream release 2.7.3
  * "??bnrL1" and "??ellL1" did not work anymore and were fixed
  * thue(f^e*g, ...), e even, (f,g)=1 missed solutions such that f<0
  * nfisincl(t_POL, t_POL) could lead to wrong negative results
  * ellcard over non-prime fields could return wrong results
  * weber(1+I) was missing its imaginary part
* Sun Oct 12 2014 jengelh@inai.de
- Update to new upstream release 2.7.2. Fixed were:
  * (gp -p N) or (primelimit=N in gprc_ for N >= 436273290 resulted
  in an incorrect primetable.
  * monomial(exact zero, d, v) returned an invalid t_POL / t_RFRAC
  * contfracpnqn(v, n) returned partial quotients p[-1]/q[-1] ...
  p[n-1]/q[n-1], instead of the documented p[0]/q[0] ... p[n]/q[n]
  * iferr() could crash if some component of the t_ERROR were clones
  * nffactor() could overflow the stack when default accuracy too low
  * obsolete use of E=[a1,a2,a3,a4,a6] in ellmul crashed
  * incorrect rounding in mulrr/divrr for one-word precision reals
  * multiif did not handle correctly return() in conditions
  * is_gener_Fp could return wrong results
  * Fq_sqrtn(t_INT,..,&zeta) could return a wrong root of 1
  * bnfinit: SEGV due to precision issues
  * zm_zc_mul only worked for square zm matrices
  * [gphelp] infinite loop when $COLUMNS too small
  * factoru(1) returned a t_MAT instead of the expected "matsmall"
  * when compatible = 3; series() used a random precision
  * isprime() could crash on large input
  * gphelp did not handle === correctly
* Wed Aug  6 2014 jengelh@inai.de
- Update to new upstream release 2.7.1
  * Q_pvalrem(t_FRAC) returned a wrong result
  * The "ellheegner" function was using too much memory in some cases
  * nfhilbert(K,x,y, P above 2) could give wrong results
  * nfpow_u didn't handle non-integral rational numbers
  * nfroots(, t_POL with leading coeff -1) could miss solutions
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 2.7.0
  * added new library functions FlxX_to_FlxC, FlxXV_to_FlxM, polx_FlxX,
  Flx_lead, RgV_to_RgM
* Wed Feb  5 2014 jengelh@inai.de
- Update to new upstream release 2.5.5
  * sin'(1) with default(compatible,3) caused a crash
  * add missing call to normalize() in lift(t_POL/t_SER)
  * galoisinit(x^3+x^2-2*x-1) led to uninitialized read
  * polred() could return non-squarefree polynomials
  * bnrdisc could return a wrong result if the modulus had more than
  2 prime divisors
  * FFT mulii relied on unspecified order of evaluation
  * local() could corrupt polynomial variable of the same name
- Add pari-nodate.diff
* Sun Jan  6 2013 jengelh@inai.de
- Restore original library filename after confirming with upstream
  (This change is transparent to all users)
* Thu Nov 29 2012 jengelh@inai.de
- Update to new upstream release 2.5.3
  * Fixed a bug whereby calling a GP function with a lot of omitted
  arguments could crash
  * idealramgroups() and idealfrobenius() did not accept a bnf
* Sun Feb 26 2012 scorot@free.fr
- fix build requirement to allow build on SLE-11
- recompress source file to bzip2 format to allow build on SLE-11
- add missing %%%%post and %%%%postun scriptlets
* Mon Sep 26 2011 jengelh@medozas.de
- Initial package (version 2.5.0) for build.opensuse.org
